<?php /*

 Composr
 Copyright (c) ocProducts, 2004-2016

 See text/EN/licence.txt for full licencing information.

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  ocProducts Ltd
 * @package    composr_tutorials
 */

/**
 * Hook class.
 */
class Hook_addon_registry_composr_tutorials
{
    /**
     * Get a list of file permissions to set
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array($runtime = false)
    {
        return array();
    }

    /**
     * Get the version of Composr this addon is for
     *
     * @return float Version number
     */
    public function get_version()
    {
        return cms_version_number();
    }

    /**
     * Get the addon category
     *
     * @return string The category
     */
    public function get_category()
    {
        return 'Admin Utilities';
    }

    /**
     * Get the addon author
     *
     * @return string The author
     */
    public function get_author()
    {
        return 'Chris Graham';
    }

    /**
     * Find other authors
     *
     * @return array A list of co-authors that should be attributed
     */
    public function get_copyright_attribution()
    {
        return array();
    }

    /**
     * Get the addon licence (one-line summary only)
     *
     * @return string The licence
     */
    public function get_licence()
    {
        return 'Licensed on the same terms as Composr';
    }

    /**
     * Get the description of the addon
     *
     * @return string Description of the addon
     */
    public function get_description()
    {
        return 'A downloadable archive of the Composr documentation.

To view this documentation load up the [tt]docs:tutorials[/tt] page-link (i.e. [tt]/docs/index.php?page=tutorials[/tt]).

You may also wish to edit the \'docs\' zone to change the "Default page" to [tt]tutorials[/tt].

You can also use the Debranding tool from the Admin Zone to make documentation point towards your own install, by setting your own site\'s base URL as the brand URL.

The documentation is primarily maintained on our website, and this archive is only provided for those who wish to view it offline, or for availability if our website is ever offline.';
    }

    /**
     * Get a list of tutorials that apply to this addon
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials()
    {
        return array();
    }

    /**
     * Get a mapping of dependency types
     *
     * @return array File permissions to set
     */
    public function get_dependencies()
    {
        return array(
            'requires' => array(),
            'recommends' => array(
                'composr_homesite',
                'composr_homesite_support_credits',
                'composr_release_build',
            ),
            'conflicts_with' => array()
        );
    }

    /**
     * Explicitly say which icon should be used
     *
     * @return URLPATH Icon
     */
    public function get_default_icon()
    {
        return 'themes/default/images/icons/48x48/menu/adminzone/help.png';
    }

    /**
     * Get a list of files that belong to this addon
     *
     * @return array List of files
     */
    public function get_file_list()
    {
        return array(
            'sources_custom/hooks/systems/addon_registry/composr_tutorials.php',
            'data_custom/build_tutorials_addon_registry_parts.php',
            'sources_custom/tutorials.php',
            'sources_custom/blocks/main_tutorial_rating.php',
            'sources_custom/blocks/main_tutorials_carousel.php',
            'data_custom/modules/docs/index.html',
            'data_custom/modules/docs/documents-Jungle.zip',
            'data_custom/modules/docs/documents-Paradise.zip',
            'themes/default/images_custom/tutorial_icons/index.html',
            'themes/default/templates_custom/BLOCK_MAIN_TUTORIALS_CAROUSEL.tpl',
            'themes/default/templates_custom/BLOCK_MAIN_TUTORIAL_RATING.tpl',
            'themes/default/templates_custom/TUTORIAL_INDEX_SCREEN.tpl',
            'themes/default/templates_custom/TUTORIAL_BOX.tpl',
            'lang_custom/EN/tutorials.ini',
            'sources_custom/hooks/systems/snippets/tutorial_box.php',
            'adminzone/pages/minimodules_custom/doc_index_build.php',
            'cms/pages/modules_custom/cms_tutorials.php',
            'sources_custom/hooks/modules/search/tutorials_external.php',
            'docs/pages/modules_custom/tutorials.php',
            'docs/index.php',
            'docs/pages/.htaccess',
            'docs/pages/index.html',
            'docs/pages/html/.htaccess',
            'docs/pages/html/EN/.htaccess',
            'docs/pages/html/EN/index.html',
            'docs/pages/html/index.html',
            'docs/pages/minimodules/.htaccess',
            'docs/pages/minimodules/index.html',
            'docs/pages/minimodules_custom/.htaccess',
            'docs/pages/minimodules_custom/index.html',
            'docs/pages/modules/.htaccess',
            'docs/pages/modules/index.html',
            'docs/pages/modules_custom/.htaccess',
            'docs/pages/modules_custom/index.html',
            'docs/pages/comcode/.htaccess',
            'docs/pages/comcode/index.html',
            'docs/pages/comcode/EN/.htaccess',
            'docs/pages/comcode/EN/index.html',
            'docs/pages/comcode_custom/.htaccess',
            'docs/pages/comcode_custom/index.html',
            'docs/pages/comcode_custom/EN/.htaccess',
            'docs/pages/comcode_custom/EN/index.html',
            'data_custom/images/docs/index.html',

            'data_custom/images/docs/advantage.png',
            'data_custom/images/docs/codebook/mvc_admin.png',
            'data_custom/images/docs/codebook/mvc_site.png',
            'data_custom/images/docs/codebook/1.jpg',
            'data_custom/images/docs/codebook/octocat.jpg',
            'data_custom/images/docs/codebook_1/1.jpg',
            'data_custom/images/docs/codebook_1/2.jpg',
            'data_custom/images/docs/codebook_1/3.jpg',
            'data_custom/images/docs/codebook_1/4.jpg',
            'data_custom/images/docs/codebook_1/5.jpg',
            'data_custom/images/docs/codebook_1/6.jpg',
            'data_custom/images/docs/codebook_1/7.jpg',
            'data_custom/images/docs/codebook_1/8.jpg',
            'data_custom/images/docs/codebook_1/flow.png',
            'data_custom/images/docs/codebook_1b/tempcode_object.png',
            'data_custom/images/docs/codebook_1b/1.jpg',
            'data_custom/images/docs/codebook_1b/2.jpg',
            'data_custom/images/docs/codebook_1b/3.jpg',
            'data_custom/images/docs/codebook_1b/4.jpg',
            'data_custom/images/docs/codebook_1b/winmerge.png',
            'data_custom/images/docs/codebook_2/1.jpg',
            'data_custom/images/docs/codebook_2/png.png',
            'data_custom/images/docs/codebook_3/1.jpg',
            'data_custom/images/docs/codebook_3/2.jpg',
            'data_custom/images/docs/codebook_3/3.jpg',
            'data_custom/images/docs/codebook_3/4.jpg',
            'data_custom/images/docs/disadvantage.png',
            'data_custom/images/docs/faq/balanced_approach.png',
            'data_custom/images/docs/dont.png',
            'data_custom/images/docs/remember.png',
            'docs/pages/comcode_custom/EN/sup_staging_servers.txt',
            'data_custom/images/docs/tut_intl_maintenance/continents-975936_1280.jpg',
            'data_custom/images/docs/sup_irrational_behaviour/image.png',
            'data_custom/images/docs/sup_forum_separation/1.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image2.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image3.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image4.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image5.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image6.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/image7.jpg',
            'data_custom/images/docs/sup_choosing_a_developer/criteria.png',
            'data_custom/images/docs/sup_complex_projects/image2.jpg',
            'data_custom/images/docs/sup_complex_projects/image3.jpg',
            'data_custom/images/docs/sup_complex_projects/good_approach.png',
            'data_custom/images/docs/sup_customer_feedback/image.jpg',
            'data_custom/images/docs/sup_customer_feedback/image.png',
            'data_custom/images/docs/sup_developer_relationships/image.jpg',
            'data_custom/images/docs/sup_developer_relationships/crazy_day.png',
            'data_custom/images/docs/sup_marketing/image.jpg',
            'data_custom/images/docs/sup_marketing/image2.jpg',
            'data_custom/images/docs/sup_marketing/kinds.png',
            'data_custom/images/docs/sup_minimum_viable_products/image.jpg',
            'data_custom/images/docs/sup_minimum_viable_products/image2.jpg',
            'data_custom/images/docs/sup_minimum_viable_products/illustration.png',
            'data_custom/images/docs/sup_modsecurity/image.jpg',
            'data_custom/images/docs/sup_pricing/image.jpg',
            'data_custom/images/docs/sup_pricing/image2.jpg',
            'data_custom/images/docs/sup_pricing/image3.jpg',
            'data_custom/images/docs/sup_pricing/image4.jpg',
            'data_custom/images/docs/sup_pricing/image5.jpg',
            'data_custom/images/docs/sup_pricing/compare.png',
            'data_custom/images/docs/sup_project_management/image.jpg',
            'data_custom/images/docs/sup_project_management/image2.jpg',
            'data_custom/images/docs/sup_project_management/roles.png',
            'data_custom/images/docs/tut_email/image.jpg',
            'data_custom/images/docs/tut_how_internet_works/globe.jpg',
            'data_custom/images/docs/tut_how_internet_works/wiring.jpg',
            'data_custom/images/docs/tut_how_internet_works/web.jpg',
            'data_custom/images/docs/tut_how_internet_works/handshake.jpg',
            'data_custom/images/docs/tut_how_internet_works/security.jpg',
            'data_custom/images/docs/tut_cookies/image.png',
            'data_custom/images/docs/tut_domain_names/lookup.png',
            'data_custom/images/docs/tut_domain_names/register.png',
            'data_custom/images/docs/tut_email/image.png',
            'data_custom/images/docs/tut_how_internet_works/image.png',
            'data_custom/images/docs/tut_keymap/image.png',
            'data_custom/images/docs/tut_staff_advice/image.jpg',
            'data_custom/images/docs/tut_staff_advice/image2.jpg',
            'data_custom/images/docs/tut_information/image.jpg',
            'data_custom/images/docs/tut_information/image2.jpg',
            'data_custom/images/docs/tut_users/image.png',
            'data_custom/images/docs/sup_staging_servers/process.jpg',
            'data_custom/images/docs/sup_postgresql/postgresql_logo.png',
            'data_custom/images/docs/sup_sqlserver/sqlserver_logo.png',
            'data_custom/images/docs/sup_hardcore_blocks/standard_nerd.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step1.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step2.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step3.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step4.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step5.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step6.jpg',
            'data_custom/images/docs/tut_google_analytics/experiment_step7.jpg',
            'data_custom/images/docs/tut_google_analytics/goal_step1.jpg',
            'data_custom/images/docs/tut_google_analytics/goal_step2.jpg',
            'data_custom/images/docs/tut_google_analytics/goal_step3.jpg',
            'data_custom/images/docs/tut_google_analytics/goal_step4.jpg',
            'data_custom/images/docs/tut_google_analytics/goal_step5.jpg',
            'data_custom/images/docs/tut_google_analytics/goal_step6.jpg',
            'data_custom/images/docs/sup_a_detailed_look_at_the_composr_calendar_system/e09738906e7828fc1c82ca46bd7aec2d.png',
            'data_custom/images/docs/sup_a_detailed_look_at_the_composr_calendar_system/ff3fd3210c6203e28031557498b92a49.png',
            'data_custom/images/docs/sup_add_a_booking_system_to_your_composr_website/1fc0bd5af2a80d643b83038ccf3d6b9e.jpg',
            'data_custom/images/docs/sup_add_a_booking_system_to_your_composr_website/6eca0eda959b9f31460837642db0c1a0.jpg',
            'data_custom/images/docs/sup_add_a_booking_system_to_your_composr_website/7715a43ddb7bd1c95b077716d974f0df.jpg',
            'data_custom/images/docs/sup_add_a_booking_system_to_your_composr_website/91d9280c5d87c647740c05aa31679cf7.jpg',
            'data_custom/images/docs/sup_add_a_booking_system_to_your_composr_website/a53352de44dfaeee69fb8a1a8fbbf099.jpg',
            'data_custom/images/docs/sup_add_a_chatroom_to_composr/81af5751bc05343a4a0fc0732474202e.png',
            'data_custom/images/docs/sup_add_a_download_library_in_composr/0d184ecf0a75af9faf384c369d8b1625.png',
            'data_custom/images/docs/sup_add_a_new_poll_to_your_composr_website/972d8c178f0494d74020cf61ee46be1a.jpg',
            'data_custom/images/docs/sup_add_a_new_poll_to_your_composr_website/ccf46c52f7912cbb5e71cf06ffc14ff8.jpg',
            'data_custom/images/docs/sup_add_a_new_zone_in_composr/0b91c18c872c56132c4c3070cb4b08d6.png',
            'data_custom/images/docs/sup_add_a_sub_forum_to_your_composr_forum/470afb81ba8d30ec3bfc4ac2e7b7f45b.png',
            'data_custom/images/docs/sup_add_a_sub_forum_to_your_composr_forum/ab2ef192aa7a47ed01e1e430057f74b5.png',
            'data_custom/images/docs/sup_add_a_sub_forum_to_your_composr_forum/d3b7b2f5169b53c7a9811916982030c7.png',
            'data_custom/images/docs/sup_add_a_sub_forum_to_your_composr_forum/dc8f52acbb69609dec15a0917bcf4267.png',
            'data_custom/images/docs/sup_add_a_sub_forum_to_your_composr_forum/f7cb8423f1b08dd908a73f26f14268e0.png',
            'data_custom/images/docs/sup_add_a_survey_to_an_composr_website/3cacffa9285660313cbab9122ab39bb0.jpg',
            'data_custom/images/docs/sup_add_a_survey_to_an_composr_website/6adeccba5782170956785b4094367c91.jpg',
            'data_custom/images/docs/sup_add_a_twitter_feed_block_to_composr/b74982619fe12e468ba00a9c59ff6766.png',
            'data_custom/images/docs/sup_add_shoutboxes_to_composr/b0c413e5980f7bfab1ae3d7b6d7e7974.png',
            'data_custom/images/docs/sup_add_shoutboxes_to_composr/b26649fcbe9c9b88151e0ec84e3812f5.png',
            'data_custom/images/docs/sup_adding_an_activity_feed_to_your_composr_website/5f3cffdcb87391fefa9fb791afc602bb.jpg',
            'data_custom/images/docs/sup_adding_an_activity_feed_to_your_composr_website/d5e85597404052bffa53e8e97d41f912.png',
            'data_custom/images/docs/sup_adding_an_activity_feed_to_your_composr_website/ec3f75e25894405dc063cedbb45badfe.png',
            'data_custom/images/docs/sup_adding_an_image_slider_to_composr/a2c951921f40c37a7451e94648bda624.png',
            'data_custom/images/docs/sup_adding_banners_to_your_composr_website/468978b250a738acda2212a578ec9160.jpg',
            'data_custom/images/docs/sup_adding_banners_to_your_composr_website/9f58a75a98ab10d9e096cba2ab51a8fd.jpg',
            'data_custom/images/docs/sup_adding_banners_to_your_composr_website/b2e4b1d7a1dbb7f74ec7ad656d998e8f.jpg',
            'data_custom/images/docs/sup_adding_new_page_options_in_composr/cfa67582aa27e434f94dd87342c3d05a.jpg',
            'data_custom/images/docs/sup_an_introduction_to_composr/049698f7423d7d50c27c0db33631755f.png',
            'data_custom/images/docs/sup_an_introduction_to_composr/175x175.png',
            'data_custom/images/docs/sup_an_overview_of_galleries_in_composr/2a3d0e421e2721b9c45626b636a76d2b.png',
            'data_custom/images/docs/sup_an_overview_of_galleries_in_composr/97351cdb4a76efab304ccf68af4b7c32.png',
            'data_custom/images/docs/sup_backing_up_your_composr_installation/3684c16497aa5a2dd3d5b6969f24a1c7.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_1.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_10.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_11.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_12.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_13.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_14.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_2.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_3.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_4.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_5.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_6.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_7.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_8.png',
            'data_custom/images/docs/sup_catalogues/sup_catalogues_9.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/07ca9125940e8fcbf86ad3949be2e2e9.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/094dbf707da8f7ddb5270fe3f106dc20.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/27b30a0f50720ea53269b56e4775b6c1.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/57be41b64ba9ce7f3b6fbc20ff55a901.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/59e3c21f3caba01bcb56835935cfe040.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/6ae91a2d8711f16b6581f83da1bde301.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/7b7f058685b9a793e413fa15237c017e.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/a861e09bb6f5f3e12c879b9bf10e8ca0.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/b51283a5d7cb2a25d588cd4f70736ed4.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/cd79704125ae05302a423bb084ef6c61.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/df87548ca493741db3ef390931b9ce16.png',
            'data_custom/images/docs/sup_changing_the_composr_forums/e9a2bcded3d491ba6d8b449dd60f0112.png',
            'data_custom/images/docs/sup_chrome_tools/1.png',
            'data_custom/images/docs/sup_chrome_tools/10.png',
            'data_custom/images/docs/sup_chrome_tools/11.png',
            'data_custom/images/docs/sup_chrome_tools/12.png',
            'data_custom/images/docs/sup_chrome_tools/2.png',
            'data_custom/images/docs/sup_chrome_tools/3.png',
            'data_custom/images/docs/sup_chrome_tools/4.png',
            'data_custom/images/docs/sup_chrome_tools/5.png',
            'data_custom/images/docs/sup_chrome_tools/6.png',
            'data_custom/images/docs/sup_chrome_tools/7.png',
            'data_custom/images/docs/sup_chrome_tools/8.png',
            'data_custom/images/docs/sup_chrome_tools/9.png',
            'data_custom/images/docs/sup_composr_101/2348c1d2b598c623c981d7c39ffe34f8.png',
            'data_custom/images/docs/sup_composr_101/2b41a00bffccd815b349cde0ce968ed9.png',
            'data_custom/images/docs/sup_composr_101/4347a329b0d59da1c1254e7d71e8ed19.png',
            'data_custom/images/docs/sup_composr_101/775aa299d62878afb51bf7574045f913.png',
            'data_custom/images/docs/sup_composr_101/8140649df759280fe2588f4fce756d89.png',
            'data_custom/images/docs/sup_composr_101/c310a17711df345f4af529951578767f.png',
            'data_custom/images/docs/sup_composr_101/c39ff1c3e5a27fd34fe5ce06d6246036.png',
            'data_custom/images/docs/sup_composr_101/cf478a8d1a6e386bdcd1e5cf10aa2eb5.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/2f095dc08d39e9f1353ee849834f1c34.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/3873b15b479052840b7b95c8dd187805.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/39cb04d2b6a53fc054e5d8efa7410808.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/3c30e89434fd1c8914242cec98fa17fe.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/3de49f568191c94aade219f1e412b844.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/45ca431ff2b26a84c2d2b8a1c07626f5.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/99aa16c5e9966c7d45d552b4479e2f0d.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/bb879ca888842e0524ddb4d9d71b0d2f.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/c53189e6acdd9def154333a00c24df64.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/f38e1ed8fe6b3981005af16c8cbcfa0f.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/f4bf3fdd200ab88f49f6c7eaa93ced48.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/f4de0ce6ba1cefe7152660f0846786ce.png',
            'data_custom/images/docs/sup_composr_custom_profile_fields_cpf/f98fbc271a614649da99cb3c4a7b7500.png',
            'data_custom/images/docs/sup_composr_points_explained/4c3ee0bc6145f83f44b041003faeb34b.jpg',
            'data_custom/images/docs/sup_configure_the_news_display_in_composr/3fb3b3088ca1d62559f7bd9900408d25.png',
            'data_custom/images/docs/sup_configure_the_news_display_in_composr/813fd3bd933d0ef16724edf575399493.png',
            'data_custom/images/docs/sup_configure_the_news_display_in_composr/dadd0a6f3478911e271a12a936ea7d31.png',
            'data_custom/images/docs/sup_converting_an_composr_gallery_to_a_carousel/b9161f6050c814dc6c6acc965e77d7ba.jpg',
            'data_custom/images/docs/sup_creating_a_hidden_members_zone_in_composr/34192953fcca3188147739c0cd7c800d.jpg',
            'data_custom/images/docs/sup_creating_a_hidden_members_zone_in_composr/582992345a4a97857cc26a3793c9583a.jpg',
            'data_custom/images/docs/sup_creating_a_store_locator_for_your_composr_website/10cb8d619f53eb42fc1cd409461ba04a.jpg',
            'data_custom/images/docs/sup_creating_a_store_locator_for_your_composr_website/dd7a698ac9d7b71854c6c3fa11676a8b.png',
            'data_custom/images/docs/sup_creating_a_store_locator_for_your_composr_website/e2ef09e73f1202b4c3b3556b1d4c049c.jpg',
            'data_custom/images/docs/sup_customising_your_composr_websites_design/13fcdc8b191c7abad8b5a613b9fcc229.png',
            'data_custom/images/docs/sup_customising_your_composr_websites_design/50ac1daa2ff0466144544b2e5131a270.png',
            'data_custom/images/docs/sup_customising_your_composr_websites_design/567de6f8400484095462e262c19d2e08.png',
            'data_custom/images/docs/sup_customising_your_composr_websites_design/5c94dbeb90a34b742e0709fefa0cd37a.png',
            'data_custom/images/docs/sup_customising_your_composr_websites_design/afe31d9f4337eb03893618764d23dac5.png',
            'data_custom/images/docs/sup_web_standards_in_composr/preview.png',
            'data_custom/images/docs/sup_database_enums/sup_database_enums_1.png',
            'data_custom/images/docs/sup_database_enums/sup_database_enums_2.png',
            'data_custom/images/docs/sup_database_enums/sup_database_enums_3.png',
            'data_custom/images/docs/sup_database_enums/sup_database_enums_4.png',
            'data_custom/images/docs/sup_database_enums/sup_database_enums_5.png',
            'data_custom/images/docs/sup_database_enums/sup_database_enums_6.png',
            'data_custom/images/docs/sup_editing_menus_in_composr/2345b8f8816ee40d6bd1f39cf73bf545.jpg',
            'data_custom/images/docs/sup_editing_menus_in_composr/9a1be81076fbaada971ead4643d63239.png',
            'data_custom/images/docs/sup_editing_menus_in_composr/e4887d7c4a51e36c25ba6e827a0c6001.jpg',
            'data_custom/images/docs/sup_editing_site_wide_permissions_in_composr/17268a4ed6de3a9eee84ac94dbf9644b.jpg',
            'data_custom/images/docs/sup_editing_site_wide_permissions_in_composr/83d33d7280975dd2bd12b1c710241a93.jpg',
            'data_custom/images/docs/sup_editing_the_composr_front_page/03dee74af0e51a80c0c92f1c66ef2feb.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/08ddbacb1cabf20727efffda709c0cda.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/3849400613dd438a681cd470a8d13cde.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/57607dd7f673251eced1a8f3eeae2a4d.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/5f87bc6f938f0f39db946715430d4d3b.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/639e316ac6165c66e51603125e928865.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/895425e4c9f62174994ae0e642752a67.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/a50d0fc866a7a495805a873fcbf1e11a.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/b08bc913642603183e7b43c235c16f58.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/b0be53bc1e5fd262e60946b758480156.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/b5f7604f27c0513a96a7afa95316122b.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/cca8cf121b8aa603026e2b4e1fe61046.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/d6d33c25d922345d59a6c4a6a12aa286.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/f96a3c729d7fe2e837de24035e5f9282.png',
            'data_custom/images/docs/sup_editing_the_composr_front_page/fe5e98e01c8520a25bbac1dc9cf515b3.png',
            'data_custom/images/docs/sup_explaining_the_composr_quiz_module/08d0ad3462393c69f00ae696c2579161.jpg',
            'data_custom/images/docs/sup_explaining_the_composr_quiz_module/6aa1f8897b481960baa0177d65e6ebce.jpg',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/3b1a3795f7ad21c858d0de7d0d67900a.png',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/51450ad2199cca376519a1e96103ed32.png',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/96bb497086de6923a85cd28697914704.png',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/a58fbe428b321e332ef57e10278bddc6.png',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/e47c5e81b3a9668c5e9fa4e6fbebade2.png',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/f2c4013ba5e5f2f338b107399cd3236e.png',
            'data_custom/images/docs/sup_finding_your_way_around_the_composr_adminzone/fbe4af1db2a14fe667e670c04cd2a52a.png',
            'data_custom/images/docs/sup_hardcore_1/hardcore_browser.png',
            'data_custom/images/docs/sup_hardcore_1/hardcore_count.png',
            'data_custom/images/docs/sup_hardcore_1/hardcore_editor.png',
            'data_custom/images/docs/sup_hardcore_1/hardcore_windows.png',
            'data_custom/images/docs/sup_hardcore_2/hardcore_censor.png',
            'data_custom/images/docs/sup_hardcore_3/hardcore_online.png',
            'data_custom/images/docs/sup_hardcore_blocks/osm.png',
            'data_custom/images/docs/sup_hardcore_blocks/point_chart.png',
            'data_custom/images/docs/sup_how_to_add_an_information_block_to_composr/0ce404d5e2079e2ec6fac2970e08efdd.png',
            'data_custom/images/docs/sup_how_to_add_an_information_block_to_composr/28d1ece9280799406a628918ff09b893.png',
            'data_custom/images/docs/sup_how_to_add_an_information_block_to_composr/58183b68fe9a655790e70957d15ea6b1.png',
            'data_custom/images/docs/sup_how_to_change_your_favicon_and_site_logo_in_composr/6730e9fff2f0a79c96632f20d83e7839.png',
            'data_custom/images/docs/sup_how_to_change_your_favicon_and_site_logo_in_composr/f05a862f267ab16aa505d7a67e9346cd.png',
            'data_custom/images/docs/sup_how_to_close_or_open_your_composr_website/d5b43a8b1d70f40114682cff2ba319aa.png',
            'data_custom/images/docs/sup_how_to_conduct_an_upgrade_in_composr/548a50de96ce065e02e056688b18c71f.png',
            'data_custom/images/docs/sup_how_to_conduct_an_upgrade_in_composr/5b111f854937fa6e26e1bfc6abe46de9.png',
            'data_custom/images/docs/sup_how_to_conduct_an_upgrade_in_composr/f559c1c2d04fd47a9c4a8f8f2cec4362.png',
            'data_custom/images/docs/sup_how_to_install_an_addon_in_composr/1edbd3b3ee87d425c87035a92fa6bcbc.png',
            'data_custom/images/docs/sup_install_a_theme_in_composr/1378b0c954bf8a84c9cdb50c1dd21ed1.jpg',
            'data_custom/images/docs/sup_install_a_theme_in_composr/6841cbb6631964ec480f959050484f25.jpg',
            'data_custom/images/docs/sup_integrating_a_youtube_channel_to_composr/b941b503b5c8e6ca7e0ad6f4b31e8a06.png',
            'data_custom/images/docs/sup_join_disabling/join_disabled.png',
            'data_custom/images/docs/sup_join_disabling/matchkey_denied.png',
            'data_custom/images/docs/sup_join_disabling/permissions.png',
            'data_custom/images/docs/sup_join_disabling/pte_guests.png',
            'data_custom/images/docs/sup_keeping_track_of_your_composr_site/0e59701aaac2a09572f9b1fed9abc181.png',
            'data_custom/images/docs/sup_making_a_theme/copying_a_theme.jpg',
            'data_custom/images/docs/sup_making_a_theme/making_a_theme.jpg',
            'data_custom/images/docs/sup_partner_sites_and_debranding_in_composr/b174fee9dcdde94b06a8f869cca8422e.jpg',
            'data_custom/images/docs/sup_security_in_composr/e53f650ddf69d937e2fe111dd9c5d254.png',
            'data_custom/images/docs/sup_sending_email_newsletters_in_composr_part_1/cdb6183ff5a84b607f3680621ba8c408.png',
            'data_custom/images/docs/sup_sending_email_newsletters_in_composr_part_1/d9eb956e96f606c8e9a516dc9bc0ed57.png',
            'data_custom/images/docs/sup_sending_email_newsletters_in_composr_part_2/d4de1fef69c64aeab7efa38e2e7aad48.png',
            'data_custom/images/docs/sup_sending_email_newsletters_in_composr_part_2/e4de1fef69c64aeab7efa38e2e7aad48.png',
            'data_custom/images/docs/sup_set_a_recurring_event_in_composr/2ec7ba1cc450963586f8dcdaae3bc137.png',
            'data_custom/images/docs/sup_set_a_recurring_event_in_composr/5319130308aee3edc16f491a9c1d1795.png',
            'data_custom/images/docs/sup_set_a_recurring_event_in_composr/b366d4e8e4c4cb0f6a72b390ca3b8098.png',
            'data_custom/images/docs/sup_set_up_a_workflow_in_composr/305f3284473e0a9f8afba50c2401539d.png',
            'data_custom/images/docs/sup_set_up_a_workflow_in_composr/8705f92d256c0b166f2fb99385f3d25e.png',
            'data_custom/images/docs/sup_set_up_a_workflow_in_composr/ad5913f2b21e4083d3dc8b33e88a119d.png',
            'data_custom/images/docs/sup_set_up_short_urls_in_composr/933b938b372c8052e33f15462f109f03.png',
            'data_custom/images/docs/sup_setting_timed_content_for_composr_and_your_arvixe_webhosting/12b04614d68047cd137a544f6a7574db.png',
            'data_custom/images/docs/sup_setting_timed_content_for_composr_and_your_arvixe_webhosting/57f66838280e912a20f65c17f71326a3.png',
            'data_custom/images/docs/sup_setting_timed_content_for_composr_and_your_arvixe_webhosting/a99fdbadd75b4964d8f19460bee58de8.png',
            'data_custom/images/docs/sup_setting_up_a_map_of_your_composr_users_locations/36431db678a1f9ea24fbe0f862f561e8.png',
            'data_custom/images/docs/sup_setting_up_a_map_of_your_composr_users_locations/41b4f04ecba1fcb62cefc6da2e694f6e.jpg',
            'data_custom/images/docs/sup_setting_up_a_new_composr_forum/2158da2e04f24337f8c08a2321185a3e.png',
            'data_custom/images/docs/sup_setting_up_a_new_composr_forum/58f0c14238520080101db3e8785848a9.png',
            'data_custom/images/docs/sup_setting_up_a_new_composr_forum/b99d7968db37c8f2ce92e47fa1649768.png',
            'data_custom/images/docs/sup_setting_up_classified_ads_on_composr/77d7920b7c1578ad26210409b518b9fe.jpg',
            'data_custom/images/docs/sup_setting_up_google_ads_in_composr/55b19319847f12b8316dba48e4e3e4c8.jpg',
            'data_custom/images/docs/sup_setup_a_new_usergroup_in_composr/41d897275dbbca81c37e38568a3efe81.png',
            'data_custom/images/docs/sup_setup_a_new_usergroup_in_composr/be101f026eff427dcec4345620a62d78.png',
            'data_custom/images/docs/sup_setup_a_new_usergroup_in_composr/ccf7c11a6a8ca8fb83b9e2ccfab60320.png',
            'data_custom/images/docs/sup_setup_a_new_usergroup_in_composr/e2be9cb2b752024ea3e7c383a0d7a985.png',
            'data_custom/images/docs/sup_setup_a_private_members_forum_in_composr/262d454624a25bca300be9e4ced68aaf.png',
            'data_custom/images/docs/sup_setup_a_private_members_forum_in_composr/83c9a18ac46abb35f7d65a27ac5e587c.png',
            'data_custom/images/docs/sup_setup_a_wiki_in_composr/5967390f4593a5ce594771bbb0c4fc5c.jpg',
            'data_custom/images/docs/sup_setup_a_wiki_in_composr/a6dc85a346a568a0a5e02fcb93be5d9b.jpg',
            'data_custom/images/docs/sup_stopping_spammers_in_composr/31d5492eee8bc0536ebb464f4a4e3d7a.jpg',
            'data_custom/images/docs/sup_stopping_spammers_in_composr/41d5492eee8bc0536ebb464f4a4e3d7a.jpg',
            'data_custom/images/docs/sup_taking_a_look_at_seo_on_composr/884fc408ae8971458bdda36e2a27071f.png',
            'data_custom/images/docs/sup_taking_a_more_detailed_look_at_composr_catalogues_system/230ba37f1077fd7ae9cea85f9edac780.png',
            'data_custom/images/docs/sup_taking_a_more_detailed_look_at_composr_catalogues_system/3d26c8be879f4ef010fa045024eed812.png',
            'data_custom/images/docs/sup_taking_a_more_detailed_look_at_composr_catalogues_system/7b60b17ffa06b3e638aa5324dc846df9.png',
            'data_custom/images/docs/sup_updating_the_members_listing_in_composr/0983a9f464db031362356f731ece828d.jpg',
            'data_custom/images/docs/sup_updating_the_members_listing_in_composr/3866360e8d6b1f5af2c3a16c74b0909c.jpg',
            'data_custom/images/docs/tip.png',
            'data_custom/images/docs/sup_catalogue_field_references/referenced_catalogue.png',
            'data_custom/images/docs/sup_catalogue_field_references/referenced_entry.png',
            'data_custom/images/docs/sup_catalogue_field_references/referencing_catalogue.png',
            'data_custom/images/docs/sup_catalogue_field_references/referencing_entry.png',
            'data_custom/images/docs/sup_catalogue_field_references/working_referenced.png',
            'data_custom/images/docs/sup_catalogue_field_references/working_referencing.png',
            'data_custom/images/docs/tut_accessibility/accessibility_colour_useful_not_needed.png',
            'data_custom/images/docs/tut_accessibility/accessibility_enable_webstandards_checker.png',
            'data_custom/images/docs/tut_accessibility/accessibility_labels.png',
            'data_custom/images/docs/tut_accessibility/accessibility_lynx.png',
            'data_custom/images/docs/tut_accessibility/accessibility_webstandards_checker.png',
            'data_custom/images/docs/tut_adminzone/adminzone_first_glance.png',
            'data_custom/images/docs/tut_adminzone/adminzone_notes.png',
            'data_custom/images/docs/tut_adminzone/adminzone_todo_list.png',
            'data_custom/images/docs/tut_adminzone/search.png',
            'data_custom/images/docs/tut_adminzone/search_results.png',
            'data_custom/images/docs/tut_adv_comcode/adv_comcode_custom.png',
            'data_custom/images/docs/tut_adv_comcode/cct_example_1.png',
            'data_custom/images/docs/tut_adv_comcode/cct_example_2.png',
            'data_custom/images/docs/tut_adv_comcode/cct_example_3.png',
            'data_custom/images/docs/tut_adv_comcode/comcode_menu.png',
            'data_custom/images/docs/tut_adv_comcode_pages/add_block_button.png',
            'data_custom/images/docs/tut_adv_comcode_pages/block_add.png',
            'data_custom/images/docs/tut_adv_comcode_pages/block_add_2.png',
            'data_custom/images/docs/tut_adv_comcode_pages/comcode_pages_blocks.png',
            'data_custom/images/docs/tut_adv_comcode_pages/wysiwyg.png',
            'data_custom/images/docs/tut_adv_configuration/addons_import.png',
            'data_custom/images/docs/tut_adv_configuration/addons_install.png',
            'data_custom/images/docs/tut_adv_configuration/addons_list.png',
            'data_custom/images/docs/tut_adv_configuration/adv_config_privileges.png',
            'data_custom/images/docs/tut_adv_configuration/installation_options.png',
            'data_custom/images/docs/tut_adv_configuration/phpsettings.png',
            'data_custom/images/docs/tut_adv_downloads/adv_downloads_add.png',
            'data_custom/images/docs/tut_adv_downloads/adv_downloads_charge.png',
            'data_custom/images/docs/tut_adv_downloads/adv_downloads_ftp_downloads.png',
            'data_custom/images/docs/tut_adv_galleries/adv_gallery_add.png',
            'data_custom/images/docs/tut_adv_galleries/adv_gallery_container.png',
            'data_custom/images/docs/tut_adv_galleries/adv_gallery_import.png',
            'data_custom/images/docs/tut_adv_galleries/adv_gallery_member.png',
            'data_custom/images/docs/tut_adv_galleries/adv_gallery_members.png',
            'data_custom/images/docs/tut_adv_galleries/adv_gallery_naming.png',
            'data_custom/images/docs/tut_adv_install/install_chmod.png',
            'data_custom/images/docs/tut_adv_members/adv_members_cpf.png',
            'data_custom/images/docs/tut_adv_members/adv_members_cpf_edit.png',
            'data_custom/images/docs/tut_adv_members/adv_members_cpf_space_1.png',
            'data_custom/images/docs/tut_adv_members/adv_members_cpf_space_2.png',
            'data_custom/images/docs/tut_adv_members/adv_members_merge.png',
            'data_custom/images/docs/tut_adv_members/adv_members_welcome_email.png',
            'data_custom/images/docs/tut_adv_members/member_import.png',
            'data_custom/images/docs/tut_adv_members/members_bookmarks.png',
            'data_custom/images/docs/tut_adv_members/members_bookmarks_manage.png',
            'data_custom/images/docs/tut_adv_news/adv_news_blog.png',
            'data_custom/images/docs/tut_adv_news/adv_news_blog_2.png',
            'data_custom/images/docs/tut_adv_news/adv_news_feedreader.png',
            'data_custom/images/docs/tut_adv_news/adv_news_profile.png',
            'data_custom/images/docs/tut_adv_news/adv_news_rss_1.png',
            'data_custom/images/docs/tut_adv_news/adv_news_rss_2.png',
            'data_custom/images/docs/tut_adv_news/adv_news_rss_xml.png',
            'data_custom/images/docs/tut_adv_news/adv_news_show_trackbacks.png',
            'data_custom/images/docs/tut_adv_news/adv_news_trackbacks_method.png',
            'data_custom/images/docs/tut_adv_news/main_rss_add.png',
            'data_custom/images/docs/tut_adv_news/rss_list.png',
            'data_custom/images/docs/tut_adv_permissions/permissions_match_keys.png',
            'data_custom/images/docs/tut_adv_permissions/permissions_match_keys_ex1.png',
            'data_custom/images/docs/tut_adv_permissions/permissions_match_keys_ex2.png',
            'data_custom/images/docs/tut_adv_permissions/permissions_match_keys_ex3.png',
            'data_custom/images/docs/tut_aggregate_types/edit_types.png',
            'data_custom/images/docs/tut_aggregate_types/instance_1.png',
            'data_custom/images/docs/tut_aggregate_types/instance_2.png',
            'data_custom/images/docs/tut_antispam/blackhole.png',
            'data_custom/images/docs/tut_antispam/captcha.png',
            'data_custom/images/docs/tut_antispam/settings.png',
            'data_custom/images/docs/tut_authors/authors_define.png',
            'data_custom/images/docs/tut_authors/authors_manage.png',
            'data_custom/images/docs/tut_authors/authors_view.png',
            'data_custom/images/docs/tut_backup/backup_1.png',
            'data_custom/images/docs/tut_backup/backup_2.png',
            'data_custom/images/docs/tut_backup/backup_3.png',
            'data_custom/images/docs/tut_banners/banners_action.png',
            'data_custom/images/docs/tut_banners/banners_add.png',
            'data_custom/images/docs/tut_banners/banners_config.png',
            'data_custom/images/docs/tut_banners/banners_view.png',
            'data_custom/images/docs/tut_banners/example_banner_add.png',
            'data_custom/images/docs/tut_banners/example_banner_type.png',
            'data_custom/images/docs/tut_banners/example_banner_wave.png',
            'data_custom/images/docs/tut_browsers/browsers.png',
            'data_custom/images/docs/tut_browsers/browserstack.png',
            'data_custom/images/docs/tut_calendar/calendar_add_event.png',
            'data_custom/images/docs/tut_calendar/calendar_event_types.png',
            'data_custom/images/docs/tut_calendar/calendar_interests.png',
            'data_custom/images/docs/tut_calendar/calendar_view_day.png',
            'data_custom/images/docs/tut_calendar/calendar_view_event.png',
            'data_custom/images/docs/tut_calendar/calendar_view_month.png',
            'data_custom/images/docs/tut_calendar/calendar_view_week.png',
            'data_custom/images/docs/tut_calendar/calendar_view_year.png',
            'data_custom/images/docs/tut_calendar/listing.png',
            'data_custom/images/docs/tut_catalogues/catalogues_add.png',
            'data_custom/images/docs/tut_catalogues/catalogues_add_entry.png',
            'data_custom/images/docs/tut_catalogues/catalogues_choose_to_add_to.png',
            'data_custom/images/docs/tut_catalogues/catalogues_display_type_field_maps.png',
            'data_custom/images/docs/tut_catalogues/catalogues_display_type_grid_images.png',
            'data_custom/images/docs/tut_catalogues/catalogues_display_type_tabular_listings.png',
            'data_custom/images/docs/tut_catalogues/catalogues_display_type_title_lists.png',
            'data_custom/images/docs/tut_catalogues/catalogues_do_next.png',
            'data_custom/images/docs/tut_catalogues/catalogues_edit.png',
            'data_custom/images/docs/tut_catalogues/catalogues_view_entry.png',
            'data_custom/images/docs/tut_catalogues/catalogues_view_index.png',
            'data_custom/images/docs/tut_catalogues/template_change.png',
            'data_custom/images/docs/tut_catalogues/with_xml__non_tree__category.png',
            'data_custom/images/docs/tut_catalogues/with_xml__non_tree__entry.png',
            'data_custom/images/docs/tut_catalogues/with_xml__non_tree__index.png',
            'data_custom/images/docs/tut_catalogues/with_xml__tree__category.png',
            'data_custom/images/docs/tut_catalogues/with_xml__tree__entry.png',
            'data_custom/images/docs/tut_catalogues/with_xml__tree__subcategory.png',
            'data_custom/images/docs/tut_catalogues/without_xml__non_tree__category.png',
            'data_custom/images/docs/tut_catalogues/without_xml__non_tree__entry.png',
            'data_custom/images/docs/tut_catalogues/without_xml__non_tree__index.png',
            'data_custom/images/docs/tut_catalogues/without_xml__tree__category.png',
            'data_custom/images/docs/tut_catalogues/without_xml__tree__entry.png',
            'data_custom/images/docs/tut_catalogues/without_xml__tree__subcategory.png',
            'data_custom/images/docs/tut_censor/adminzone_recent_actions.png',
            'data_custom/images/docs/tut_censor/censor_make_warning.png',
            'data_custom/images/docs/tut_censor/censor_member.png',
            'data_custom/images/docs/tut_censor/censor_point_in_right_direction.png',
            'data_custom/images/docs/tut_censor/censor_post_history.png',
            'data_custom/images/docs/tut_censor/censor_warning.png',
            'data_custom/images/docs/tut_censor/censor_word.png',
            'data_custom/images/docs/tut_censor/member_links.png',
            'data_custom/images/docs/tut_chat/chat_administration_add_chatroom.png',
            'data_custom/images/docs/tut_chat/chat_administration_chatrooms.png',
            'data_custom/images/docs/tut_chat/chat_administration_edit_chatroom.png',
            'data_custom/images/docs/tut_chat/chat_chat_inline_moderation_links.png',
            'data_custom/images/docs/tut_chat/chat_chat_message_window.png',
            'data_custom/images/docs/tut_chat/chat_chatroom_list.png',
            'data_custom/images/docs/tut_chat/chat_chatroom_options.png',
            'data_custom/images/docs/tut_chat/chat_create_private_room.png',
            'data_custom/images/docs/tut_chat/chat_delete_all_chatrooms.png',
            'data_custom/images/docs/tut_chat/chat_delete_all_messages_link.png',
            'data_custom/images/docs/tut_chat/chat_delete_all_rooms_link.png',
            'data_custom/images/docs/tut_chat/chat_download_chat_logs.png',
            'data_custom/images/docs/tut_chat/chat_download_chat_logs_link.png',
            'data_custom/images/docs/tut_chat/chat_lobby.png',
            'data_custom/images/docs/tut_chat/chat_moderation_panel_edit_message.png',
            'data_custom/images/docs/tut_chat/chat_moderation_panel_messages.png',
            'data_custom/images/docs/tut_chat/chat_moderation_panel_rooms.png',
            'data_custom/images/docs/tut_chmod/chmod_1.png',
            'data_custom/images/docs/tut_chmod/chmod_2.png',
            'data_custom/images/docs/tut_cleanup/cleanup_1.png',
            'data_custom/images/docs/tut_cleanup/cleanup_2.png',
            'data_custom/images/docs/tut_collaboration/collaboration_filedump.png',
            'data_custom/images/docs/tut_collaboration/collaboration_supermembers.png',
            'data_custom/images/docs/tut_comcode/comcode_attachment_add.png',
            'data_custom/images/docs/tut_comcode/comcode_attachment_edit.png',
            'data_custom/images/docs/tut_comcode/comcode_list.png',
            'data_custom/images/docs/tut_comcode/tag_2.png',
            'data_custom/images/docs/tut_comcode/tag_non_wysiwyg.png',
            'data_custom/images/docs/tut_comcode/tag_wysiwyg.png',
            'data_custom/images/docs/tut_comcode/tags.png',
            'data_custom/images/docs/tut_comcode_pages/add_page_box.png',
            'data_custom/images/docs/tut_comcode_pages/comcode_pages.png',
            'data_custom/images/docs/tut_comcode_pages/comcode_pages_easyadd.png',
            'data_custom/images/docs/tut_comcode_pages/comcode_pages_edit.png',
            'data_custom/images/docs/tut_comcode_pages/comcode_pages_view.png',
            'data_custom/images/docs/tut_commandr/closed.png',
            'data_custom/images/docs/tut_commandr/commandr.png',
            'data_custom/images/docs/tut_commandr/cpuinfo_linux.png',
            'data_custom/images/docs/tut_commandr/cpuinfo_mac.png',
            'data_custom/images/docs/tut_commandr/directory_sizes.png',
            'data_custom/images/docs/tut_commandr/db_table_sizes.png',
            'data_custom/images/docs/tut_commandr/php.png',
            'data_custom/images/docs/tut_commandr/query.png',
            'data_custom/images/docs/tut_commandr/uptime.png',
            'data_custom/images/docs/tut_commandr/whois.png',
            'data_custom/images/docs/tut_configuration/closed.png',
            'data_custom/images/docs/tut_configuration/configuration.png',
            'data_custom/images/docs/tut_configuration/configuration_actual.png',
            'data_custom/images/docs/tut_configuration/cron.png',
            'data_custom/images/docs/tut_configuration/logo_1.png',
            'data_custom/images/docs/tut_configuration/logo_2.png',
            'data_custom/images/docs/tut_configuration/menu_edit_link.png',
            'data_custom/images/docs/tut_configuration/menu_editor.png',
            'data_custom/images/docs/tut_configuration/reaching_adminzone.png',
            'data_custom/images/docs/tut_configuration/setup_wizard.png',
            'data_custom/images/docs/tut_correspondence/correspondence_create_pt_page.png',
            'data_custom/images/docs/tut_correspondence/correspondence_create_pt_page1.png',
            'data_custom/images/docs/tut_correspondence/correspondence_forum_notification_message.png',
            'data_custom/images/docs/tut_correspondence/correspondence_hovering_over_pt_link.png',
            'data_custom/images/docs/tut_correspondence/correspondence_hovering_over_startpt_link.png',
            'data_custom/images/docs/tut_correspondence/correspondence_new_pt.png',
            'data_custom/images/docs/tut_correspondence/correspondence_pt_page.png',
            'data_custom/images/docs/tut_correspondence/correspondence_reply_to_pt.png',
            'data_custom/images/docs/tut_correspondence/correspondence_thunderbird_notification_e_mail.png',
            'data_custom/images/docs/tut_correspondence/correspondence_whisper.png',
            'data_custom/images/docs/tut_correspondence/correspondence_whisper_form.png',
            'data_custom/images/docs/tut_correspondence/correspondence_whisper_link.png',
            'data_custom/images/docs/tut_correspondence/correspondence_whisper_page.png',
            'data_custom/images/docs/tut_design/simple_box.png',
            'data_custom/images/docs/tut_design/image.png',
            'data_custom/images/docs/tut_disaster/disaster_ban_1.png',
            'data_custom/images/docs/tut_disaster/disaster_ban_2.png',
            'data_custom/images/docs/tut_disaster/disaster_pass_1.png',
            'data_custom/images/docs/tut_disaster/disaster_pass_2.png',
            'data_custom/images/docs/tut_disaster/disaster_pass_3.png',
            'data_custom/images/docs/tut_downloads/downloads_add.png',
            'data_custom/images/docs/tut_downloads/downloads_add_category.png',
            'data_custom/images/docs/tut_downloads/downloads_deletion.png',
            'data_custom/images/docs/tut_downloads/downloads_do_next.png',
            'data_custom/images/docs/tut_downloads/downloads_edit_file.png',
            'data_custom/images/docs/tut_downloads/downloads_in_subcat.png',
            'data_custom/images/docs/tut_downloads/downloads_subcat.png',
            'data_custom/images/docs/tut_downloads/downloads_view.png',
            'data_custom/images/docs/tut_drinking/feature_rich.jpg',
            'data_custom/images/docs/tut_ecommerce/ecommerce_invoice.png',
            'data_custom/images/docs/tut_ecommerce/ecommerce_layer.png',
            'data_custom/images/docs/tut_ecommerce/ecommerce_manual.png',
            'data_custom/images/docs/tut_ecommerce/ecommerce_pl.png',
            'data_custom/images/docs/tut_ecommerce/ecommerce_subscription.png',
            'data_custom/images/docs/tut_ecommerce/product_add.png',
            'data_custom/images/docs/tut_ecommerce/product_cart.png',
            'data_custom/images/docs/tut_ecommerce/product_view.png',
            'data_custom/images/docs/tut_ecommerce/upgrade.png',
            'data_custom/images/docs/tut_ecommerce/upgrade_2.png',
            'data_custom/images/docs/tut_ecommerce/upgrade_3.png',
            'data_custom/images/docs/tut_emoticons/emoticons_add.png',
            'data_custom/images/docs/tut_facebook/facebook.png',
            'data_custom/images/docs/tut_facebook/twitter.png',
            'data_custom/images/docs/tut_facebook/facebook_headers.png',
            'data_custom/images/docs/tut_facebook/facebook_addon_a.png',
            'data_custom/images/docs/tut_facebook/facebook_addon_b.png',
            'data_custom/images/docs/tut_facebook/facebook_config.png',
            'data_custom/images/docs/tut_facebook/facebook_logout_a.png',
            'data_custom/images/docs/tut_facebook/facebook_logout_b.png',
            'data_custom/images/docs/tut_facebook/fb_composr.jpg',
            'data_custom/images/docs/tut_featured/assistant.png',
            'data_custom/images/docs/tut_featured/featured_award.png',
            'data_custom/images/docs/tut_featured/featured_award_block.png',
            'data_custom/images/docs/tut_featured/featured_checklist.png',
            'data_custom/images/docs/tut_featured/featured_dotw.png',
            'data_custom/images/docs/tut_featured/featured_forum_topics_block.png',
            'data_custom/images/docs/tut_featured/featured_iotd_add.png',
            'data_custom/images/docs/tut_featured/featured_iotd_choose.png',
            'data_custom/images/docs/tut_featured/featured_iotd_view.png',
            'data_custom/images/docs/tut_featured/featured_main_include_module.png',
            'data_custom/images/docs/tut_featured/featured_main_include_module_2.png',
            'data_custom/images/docs/tut_feedback/catalogue_add.png',
            'data_custom/images/docs/tut_feedback/catalogue_block_1.png',
            'data_custom/images/docs/tut_feedback/catalogue_block_2.png',
            'data_custom/images/docs/tut_feedback/catalogue_block_3.png',
            'data_custom/images/docs/tut_feedback/feedback_add_poll.png',
            'data_custom/images/docs/tut_feedback/feedback_contact_block.png',
            'data_custom/images/docs/tut_feedback/feedback_messaging_list.png',
            'data_custom/images/docs/tut_feedback/feedback_no_poll.png',
            'data_custom/images/docs/tut_feedback/feedback_poll.png',
            'data_custom/images/docs/tut_feedback/feedback_poll_page.png',
            'data_custom/images/docs/tut_feedback/messaging_message.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__author.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__codename.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__color.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__content_link.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__content_link_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__date.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__email.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__float.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__integer.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__isbn.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__just_date.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__just_time.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list__dropdown.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list__inline.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list__inline_huge.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list__radio.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list_multi__horizontal_checkboxes.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list_multi__multilist.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__list_multi__vertical_checkboxes.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__long_text.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__long_text__huge.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__long_trans.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__member.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__member_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__page_link.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__password.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__picture.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__picture_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__posting_field.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__reference.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__reference_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__short_text.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__short_text_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__short_trans.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__short_trans_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__tel.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__theme_image.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__tick__not_required.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__tick__required.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__upload.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__upload_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__url.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__url_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__video.png',
            'data_custom/images/docs/tut_fields/core_fields_backend__video_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__author.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__codename.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__color.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__content_link.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__content_link_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__date.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__email.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__float.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__guid.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__integer.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__isbn.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__just_date.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__just_time.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list__dropdown.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list__inline.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list__inline_huge.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list__radio.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list_multi__horizontal_checkboxes.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list_multi__multilist.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__list_multi__vertical_checkboxes.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__long_text.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__long_text__huge.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__long_trans.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__member.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__member_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__page_link.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__password.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__picture.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__picture_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__posting_field.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__reference.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__reference_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__short_text.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__short_text_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__short_trans.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__short_trans_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__tel.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__theme_image.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__tick__not_required.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__tick__required.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__upload.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__upload_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__url.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__url_multi.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__video.png',
            'data_custom/images/docs/tut_fields/core_fields_frontend__video_multi.png',
            'data_custom/images/docs/tut_fields_filter/xml.png',
            'data_custom/images/docs/tut_filtercode/filtercode_html.png',
            'data_custom/images/docs/tut_filtercode/filtercode_main_content_filtering.png',
            'data_custom/images/docs/tut_filtercode/filtercode_refined_filter.png',
            'data_custom/images/docs/tut_fixed_width/fixed_width.png',
            'data_custom/images/docs/tut_fixed_width/fluid_thin.png',
            'data_custom/images/docs/tut_fixed_width/fluid_wide.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_mark_forum_read_link.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_mark_topic_unread_link.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_monitor_button.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_notification_auto_options.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_notification_settings.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_posts_since_last_visit.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_posts_since_last_visit_link.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_topic_read_status.gif',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_topics_with_unread_posts.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_topics_with_unread_posts_link.png',
            'data_custom/images/docs/tut_forum_tracking/forum_tracking_unmonitor_button.png',
            'data_custom/images/docs/tut_forums/forums_add.png',
            'data_custom/images/docs/tut_forums/forums_edit.png',
            'data_custom/images/docs/tut_forums/forums_grouping_add.png',
            'data_custom/images/docs/tut_forums/forums_poll_add.png',
            'data_custom/images/docs/tut_forums/forums_poll_view_1.png',
            'data_custom/images/docs/tut_forums/forums_poll_view_2.png',
            'data_custom/images/docs/tut_forums/forums_quick_reply.png',
            'data_custom/images/docs/tut_forums/forums_view.png',
            'data_custom/images/docs/tut_forums/forums_view_2.png',
            'data_custom/images/docs/tut_framework/framework_api.png',
            'data_custom/images/docs/tut_framework/framework_code_editor_1.png',
            'data_custom/images/docs/tut_framework/framework_code_editor_2.png',
            'data_custom/images/docs/tut_framework/framework_code_editor_3.png',
            'data_custom/images/docs/tut_framework/framework_devguide.png',
            'data_custom/images/docs/tut_framework/framework_export_1.png',
            'data_custom/images/docs/tut_framework/framework_export_2.png',
            'data_custom/images/docs/tut_framework/framework_file_language.png',
            'data_custom/images/docs/tut_framework/framework_file_module.png',
            'data_custom/images/docs/tut_framework/framework_file_templates.png',
            'data_custom/images/docs/tut_framework/framework_import_1.png',
            'data_custom/images/docs/tut_framework/framework_import_2.png',
            'data_custom/images/docs/tut_framework/framework_phphelp.png',
            'data_custom/images/docs/tut_fringe/favicon.png',
            'data_custom/images/docs/tut_fringe/main_custom_gfx.png',
            'data_custom/images/docs/tut_fringe/webclipicon.png',
            'data_custom/images/docs/tut_galleries/gallery_add_image.png',
            'data_custom/images/docs/tut_galleries/gallery_flow_mode.png',
            'data_custom/images/docs/tut_galleries/gallery_not_flow_mode.png',
            'data_custom/images/docs/tut_galleries/gallery_subcat.png',
            'data_custom/images/docs/tut_galleries/gallery_view_image.png',
            'data_custom/images/docs/tut_google_appengine/appengine_create.png',
            'data_custom/images/docs/tut_google_appengine/appengine_launcher.png',
            'data_custom/images/docs/tut_google_appengine/cloud_sql.png',
            'data_custom/images/docs/tut_google_appengine/cloud_sql_database.png',
            'data_custom/images/docs/tut_google_appengine/cloud_storage_permissions_1.png',
            'data_custom/images/docs/tut_google_appengine/cloud_storage_permissions_2.png',
            'data_custom/images/docs/tut_google_appengine/composr_with_gae.jpg',
            'data_custom/images/docs/tut_google_appengine/google_cloud_services.png',
            'data_custom/images/docs/tut_google_appengine/google_cloud_storage.png',
            'data_custom/images/docs/tut_google_appengine/google_cloud_storage_link.png',
            'data_custom/images/docs/tut_httpauth/httpauth_ask.png',
            'data_custom/images/docs/tut_httpauth/httpauth_deny.png',
            'data_custom/images/docs/tut_httpauth/httpauth_disable_join.png',
            'data_custom/images/docs/tut_httpauth/httpauth_enable.png',
            'data_custom/images/docs/tut_httpauth/httpauth_finishprofile.png',
            'data_custom/images/docs/tut_importer/importer_change_forum_driver.png',
            'data_custom/images/docs/tut_importer/importer_choose.png',
            'data_custom/images/docs/tut_importer/importer_dbs.png',
            'data_custom/images/docs/tut_importer/importer_forum_drivers.png',
            'data_custom/images/docs/tut_importer/importer_imported.png',
            'data_custom/images/docs/tut_importer/importer_options.png',
            'data_custom/images/docs/tut_importer/importer_options2.png',
            'data_custom/images/docs/tut_importer/importer_session.png',
            'data_custom/images/docs/tut_importer/importer_target_config_file.png',
            'data_custom/images/docs/tut_install/congratulations.jpg',
            'data_custom/images/docs/tut_install/install_done.png',
            'data_custom/images/docs/tut_install/install_download.png',
            'data_custom/images/docs/tut_install/install_login_ftp.png',
            'data_custom/images/docs/tut_install/install_step1.png',
            'data_custom/images/docs/tut_install/install_step2_1.png',
            'data_custom/images/docs/tut_install/install_step3_1.png',
            'data_custom/images/docs/tut_install/install_step4.png',
            'data_custom/images/docs/tut_install/install_step5.png',
            'data_custom/images/docs/tut_install/install_upload_ftp.gif',
            'data_custom/images/docs/tut_install/install_upload_ftp_thumb.png',
            'data_custom/images/docs/tut_integration/integration_cc_page.png',
            'data_custom/images/docs/tut_intl/intl_crit_choose.png',
            'data_custom/images/docs/tut_intl/intl_crit_screen.png',
            'data_custom/images/docs/tut_intl/intl_pack.png',
            'data_custom/images/docs/tut_intl/intl_phpmyadmin_settings.png',
            'data_custom/images/docs/tut_intl/intl_trans_choose.png',
            'data_custom/images/docs/tut_intl/intl_trans_screen.png',
            'data_custom/images/docs/tut_intl_content/content.png',
            'data_custom/images/docs/tut_intl_content/side_language.png',
            'data_custom/images/docs/tut_intl_users/intl_config.png',
            'data_custom/images/docs/tut_intl_users/intl_config_2.png',
            'data_custom/images/docs/tut_ldap/ldap_adduser.png',
            'data_custom/images/docs/tut_ldap/ldap_configuration.png',
            'data_custom/images/docs/tut_ldap/ldap_finishprofile.png',
            'data_custom/images/docs/tut_ldap/ldap_login.png',
            'data_custom/images/docs/tut_ldap/ldap_sync.png',
            'data_custom/images/docs/tut_legal/legal_rules.png',
            'data_custom/images/docs/tut_legal/image.png',
            'data_custom/images/docs/tut_members/members_add.png',
            'data_custom/images/docs/tut_members/members_directory.png',
            'data_custom/images/docs/tut_members/members_edit_avatar.png',
            'data_custom/images/docs/tut_members/members_edit_photo.png',
            'data_custom/images/docs/tut_members/members_edit_profile.png',
            'data_custom/images/docs/tut_members/members_edit_signature.png',
            'data_custom/images/docs/tut_members/members_edit_title.png',
            'data_custom/images/docs/tut_members/members_join.png',
            'data_custom/images/docs/tut_members/members_login.png',
            'data_custom/images/docs/tut_members/members_login_block.png',
            'data_custom/images/docs/tut_members/members_online.png',
            'data_custom/images/docs/tut_members/members_profile.png',
            'data_custom/images/docs/tut_members/recommend.png',
            'data_custom/images/docs/tut_menus/menus_add_link.png',
            'data_custom/images/docs/tut_menus/menus_edit_links.png',
            'data_custom/images/docs/tut_menus/menus_editor.png',
            'data_custom/images/docs/tut_mobile/mobile.png',
            'data_custom/images/docs/tut_mobile/mobile_menu.png',
            'data_custom/images/docs/tut_mobile_sdk/logo.jpg',
            'data_custom/images/docs/tut_mobile_sdk/android.png',
            'data_custom/images/docs/tut_mobile_sdk/phone.png',
            'data_custom/images/docs/tut_moderation/forum_helpdesk_add_multi_moderation.png',
            'data_custom/images/docs/tut_moderation/forum_helpdesk_using_multi_moderation.png',
            'data_custom/images/docs/tut_moderation/mod_edit_topic.png',
            'data_custom/images/docs/tut_moderation/mod_move_posts.png',
            'data_custom/images/docs/tut_moderation/mod_post.png',
            'data_custom/images/docs/tut_moderation/mod_posts.png',
            'data_custom/images/docs/tut_moderation/mod_topic.png',
            'data_custom/images/docs/tut_moderation/mod_topics.png',
            'data_custom/images/docs/tut_msn/msn_cns_local.png',
            'data_custom/images/docs/tut_msn/msn_netlink_block.png',
            'data_custom/images/docs/tut_msn/msn_netlink_configure.png',
            'data_custom/images/docs/tut_msn/msn_netlink_file.png',
            'data_custom/images/docs/tut_msn/msn_staff.png',
            'data_custom/images/docs/tut_msn/msn_staff_2.png',
            'data_custom/images/docs/tut_news/block_add.png',
            'data_custom/images/docs/tut_news/block_view.png',
            'data_custom/images/docs/tut_news/news_add_category.png',
            'data_custom/images/docs/tut_news/news_add_page.png',
            'data_custom/images/docs/tut_news/news_import.png',
            'data_custom/images/docs/tut_news/news_link.png',
            'data_custom/images/docs/tut_news/news_view.png',
            'data_custom/images/docs/tut_newsletter/automatic_1.png',
            'data_custom/images/docs/tut_newsletter/automatic_2.png',
            'data_custom/images/docs/tut_newsletter/newsletter_new.png',
            'data_custom/images/docs/tut_newsletter/newsletter_subscribe.png',
            'data_custom/images/docs/tut_notifications/lockdown.png',
            'data_custom/images/docs/tut_notifications/notifications.png',
            'data_custom/images/docs/tut_nuances/intro_forums.png',
            'data_custom/images/docs/tut_nuances/nuances_1.png',
            'data_custom/images/docs/tut_nuances/nuances_2.png',
            'data_custom/images/docs/tut_nuances/nuances_3.png',
            'data_custom/images/docs/tut_nuances/nuances_forum_menu_1.png',
            'data_custom/images/docs/tut_nuances/nuances_forum_menu_2.png',
            'data_custom/images/docs/tut_permissions/absorb_permissions.png',
            'data_custom/images/docs/tut_permissions/firephp.png',
            'data_custom/images/docs/tut_permissions/gallery_validation_permissions.png',
            'data_custom/images/docs/tut_permissions/permissions_choose_category_edit.png',
            'data_custom/images/docs/tut_permissions/permissions_choose_privileges.png',
            'data_custom/images/docs/tut_permissions/permissions_choose_zone_edit.png',
            'data_custom/images/docs/tut_permissions/permissions_edit_category_permissions.png',
            'data_custom/images/docs/tut_permissions/permissions_edit_privileges.png',
            'data_custom/images/docs/tut_permissions/permissions_edit_zone_permissions.png',
            'data_custom/images/docs/tut_permissions/permissions_mass_checkbox_change.gif',
            'data_custom/images/docs/tut_permissions/permissions_mass_checkbox_change1.gif',
            'data_custom/images/docs/tut_permissions/permissions_page_permissions_grid.png',
            'data_custom/images/docs/tut_permissions/permissions_su.png',
            'data_custom/images/docs/tut_permissions/permissions_tree_editor.png',
            'data_custom/images/docs/tut_points/inventory_custom.png',
            'data_custom/images/docs/tut_points/inventory_forwarding.png',
            'data_custom/images/docs/tut_points/inventory_permissions.png',
            'data_custom/images/docs/tut_points/inventory_pop3.png',
            'data_custom/images/docs/tut_points/points_admin_monitor.png',
            'data_custom/images/docs/tut_points/points_block.png',
            'data_custom/images/docs/tut_points/points_community_billboard_actual.png',
            'data_custom/images/docs/tut_points/points_community_billboard_add.png',
            'data_custom/images/docs/tut_points/points_community_billboard_manage.png',
            'data_custom/images/docs/tut_points/points_config.png',
            'data_custom/images/docs/tut_points/points_default_community_billboard.png',
            'data_custom/images/docs/tut_points/points_leader_board.png',
            'data_custom/images/docs/tut_points/points_lucky.png',
            'data_custom/images/docs/tut_points/points_page.png',
            'data_custom/images/docs/tut_points/points_pointstore.png',
            'data_custom/images/docs/tut_points/points_pointstore_config.png',
            'data_custom/images/docs/tut_points/points_prices.png',
            'data_custom/images/docs/tut_points/rank.png',
            'data_custom/images/docs/tut_points/rank_options.png',
            'data_custom/images/docs/tut_quizzes/quiz_add.png',
            'data_custom/images/docs/tut_quizzes/quiz_view.png',
            'data_custom/images/docs/tut_releasing_themes/releasing_themes_make.png',
            'data_custom/images/docs/tut_repository/os_webdav.jpg',
            'data_custom/images/docs/tut_repository/image.png',
            'data_custom/images/docs/tut_webhosting/image.png',
            'data_custom/images/docs/tut_webhosting/pick_webhost.png',
            'data_custom/images/docs/tut_webhosting/kind.png',
            'data_custom/images/docs/tut_search/search_advanced.png',
            'data_custom/images/docs/tut_search/search_block.png',
            'data_custom/images/docs/tut_search/search_details.png',
            'data_custom/images/docs/tut_search/search_forum.png',
            'data_custom/images/docs/tut_security/security_antispam.png',
            'data_custom/images/docs/tut_security/security_attack.png',
            'data_custom/images/docs/tut_security/security_cns_members.png',
            'data_custom/images/docs/tut_security/security_ip_enquire.png',
            'data_custom/images/docs/tut_security/security_logins.png',
            'data_custom/images/docs/tut_security/security_require_session.png',
            'data_custom/images/docs/tut_seo/seo_content.png',
            'data_custom/images/docs/tut_seo/seo_options.png',
            'data_custom/images/docs/tut_seo/xml_sitemap.png',
            'data_custom/images/docs/tut_short_urls/apache.png',
            'data_custom/images/docs/tut_short_urls/iis.png',
            'data_custom/images/docs/tut_software_feedback/482033_challenge.jpg',
            'data_custom/images/docs/tut_software_feedback/feature_workflow.png',
            'data_custom/images/docs/tut_software_feedback/report_bug.png',
            'data_custom/images/docs/tut_software_feedback/feedback_general.png',
            'data_custom/images/docs/tut_sql/sql_1.png',
            'data_custom/images/docs/tut_sql/sql_2.png',
            'data_custom/images/docs/tut_sql/sql_edit_1.png',
            'data_custom/images/docs/tut_sql/sql_edit_2.png',
            'data_custom/images/docs/tut_sql/sql_edit_3.png',
            'data_custom/images/docs/tut_sql/sql_plesk.png',
            'data_custom/images/docs/tut_sql/sql_repair.png',
            'data_custom/images/docs/tut_staff/staff_actual.png',
            'data_custom/images/docs/tut_staff/staff_forums_1.png',
            'data_custom/images/docs/tut_staff/staff_forums_2.png',
            'data_custom/images/docs/tut_staff/staff_list.png',
            'data_custom/images/docs/tut_staff/staff_report_1.png',
            'data_custom/images/docs/tut_staff/staff_report_2.png',
            'data_custom/images/docs/tut_staff/staff_report_3.png',
            'data_custom/images/docs/tut_statistics/realtime_rain.png',
            'data_custom/images/docs/tut_statistics/side_stats.png',
            'data_custom/images/docs/tut_statistics/statistics_download_statistics.png',
            'data_custom/images/docs/tut_statistics/statistics_icons.png',
            'data_custom/images/docs/tut_statistics/statistics_install_geolocation_data_link.png',
            'data_custom/images/docs/tut_statistics/statistics_installing_geolocation_data.png',
            'data_custom/images/docs/tut_statistics/statistics_news_item_stats.png',
            'data_custom/images/docs/tut_statistics/statistics_overview.png',
            'data_custom/images/docs/tut_statistics/statistics_page.png',
            'data_custom/images/docs/tut_statistics/statistics_page_views.png',
            'data_custom/images/docs/tut_structure/box.png',
            'data_custom/images/docs/tut_structure/breadcrumb_after.png',
            'data_custom/images/docs/tut_structure/breadcrumb_before.png',
            'data_custom/images/docs/tut_structure/breadcrumbs.png',
            'data_custom/images/docs/tut_structure/breadcrumbs_edit.png',
            'data_custom/images/docs/tut_structure/structure_main.png',
            'data_custom/images/docs/tut_structure/structure_templates.png',
            'data_custom/images/docs/tut_structure/structure_zone_editor.png',
            'data_custom/images/docs/tut_subcom/redirect_forum_complex_example.png',
            'data_custom/images/docs/tut_subcom/redirect_forum_simple_example.png',
            'data_custom/images/docs/tut_subcom/subcom_cat_add.png',
            'data_custom/images/docs/tut_subcom/subcom_cat_view.png',
            'data_custom/images/docs/tut_subcom/subcom_redirects.png',
            'data_custom/images/docs/tut_subcom/subcom_virtualised.png',
            'data_custom/images/docs/tut_subcom/subcom_zone_add.png',
            'data_custom/images/docs/tut_subcom/subcom_zone_afm.png',
            'data_custom/images/docs/tut_subcom/usergroup.png',
            'data_custom/images/docs/tut_subcom/usergroup_add.png',
            'data_custom/images/docs/tut_subcom/usergroup_directory.png',
            'data_custom/images/docs/tut_support_desk/forum_helpdesk_add_post_template.png',
            'data_custom/images/docs/tut_support_desk/forum_helpdesk_using_post_template.png',
            'data_custom/images/docs/tut_support_desk/support_feedback.png',
            'data_custom/images/docs/tut_support_desk/support_forum_config.png',
            'data_custom/images/docs/tut_support_desk/support_list_tickets.png',
            'data_custom/images/docs/tut_support_desk/support_show_ticket.png',
            'data_custom/images/docs/tut_support_desk/support_ticket_types.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp1.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp2.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp3.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp4.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp5.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp6.png',
            'data_custom/images/docs/tut_tempcode/poweroftemp7.png',
            'data_custom/images/docs/tut_theme_lifecycle/diffmerge.png',
            'data_custom/images/docs/tut_themes/add_image_1.png',
            'data_custom/images/docs/tut_themes/add_image_2.png',
            'data_custom/images/docs/tut_themes/add_image_3.png',
            'data_custom/images/docs/tut_themes/add_image_4.png',
            'data_custom/images/docs/tut_themes/add_image_5.png',
            'data_custom/images/docs/tut_themes/button.png',
            'data_custom/images/docs/tut_themes/edit_theme_image.png',
            'data_custom/images/docs/tut_themes/intro_themes.png',
            'data_custom/images/docs/tut_themes/manage_themes.png',
            'data_custom/images/docs/tut_themes/rendering_tools.png',
            'data_custom/images/docs/tut_themes/themes_choose_css.png',
            'data_custom/images/docs/tut_themes/themes_edit_css.png',
            'data_custom/images/docs/tut_themes/themes_edit_templates.png',
            'data_custom/images/docs/tut_themes/themes_page_tree.png',
            'data_custom/images/docs/tut_themes/themes_tree_go.png',
            'data_custom/images/docs/tut_themes/themewizard.png',
            'data_custom/images/docs/tut_trace/trace_dig_1.png',
            'data_custom/images/docs/tut_trace/trace_dig_2.png',
            'data_custom/images/docs/tut_trace/trace_dnsstuff.png',
            'data_custom/images/docs/tut_trace/trace_investigate_1.png',
            'data_custom/images/docs/tut_trace/trace_investigate_2.png',
            'data_custom/images/docs/tut_trace/trace_ip_bans.png',
            'data_custom/images/docs/tut_trace/trace_menu.png',
            'data_custom/images/docs/tut_trace/trace_menu2.png',
            'data_custom/images/docs/tut_uninstall/uninstall_1.png',
            'data_custom/images/docs/tut_upgrade/integrity_1.png',
            'data_custom/images/docs/tut_upgrade/integrity_2.png',
            'data_custom/images/docs/tut_upgrade/upgrade.png',
            'data_custom/images/docs/tut_upgrade/upgrade_login.png',
            'data_custom/images/docs/tut_webapp/intro_1.png',
            'data_custom/images/docs/tut_webapp/intro_2.png',
            'data_custom/images/docs/tut_webapp/webapp_architecture.png',
            'data_custom/images/docs/tut_webapp/webapp_login.png',
            'data_custom/images/docs/tut_wiki/wiki_page.png',
            'data_custom/images/docs/tut_wiki/wiki_post.png',
            'data_custom/images/docs/tut_wiki/wiki_tree_edit.png',
            'data_custom/images/docs/tut_windows/bitnami.png',
            'data_custom/images/docs/tut_windows/apache.png',
            'data_custom/images/docs/tut_windows/mysql.png',
            'data_custom/images/docs/tut_windows/php.png',
            'data_custom/images/docs/tut_windows/wampserver.png',
            'data_custom/images/docs/tut_windows/wampserver_composr.jpg',
            'data_custom/images/docs/tut_windows/wampserver_mysql.jpg',
            'data_custom/images/docs/tut_windows/windows_perm1.png',
            'data_custom/images/docs/tut_windows/windows_perm2.png',
            'data_custom/images/docs/tut_windows/windows_perm_reset.png',
            'data_custom/images/docs/tut_wysiwyg/wysiwyg.png',
            'data_custom/images/docs/sup_running_agency/1.jpg',
            'data_custom/images/docs/sup_running_agency/10.jpg',
            'data_custom/images/docs/sup_running_agency/11.jpg',
            'data_custom/images/docs/sup_running_agency/12.jpg',
            'data_custom/images/docs/sup_running_agency/13.jpg',
            'data_custom/images/docs/sup_running_agency/2.jpg',
            'data_custom/images/docs/sup_running_agency/3.jpg',
            'data_custom/images/docs/sup_running_agency/4.jpg',
            'data_custom/images/docs/sup_running_agency/5.jpg',
            'data_custom/images/docs/sup_running_agency/6.jpg',
            'data_custom/images/docs/sup_running_agency/7.jpg',
            'data_custom/images/docs/sup_running_agency/8.jpg',
            'data_custom/images/docs/sup_running_agency/9.jpg',
            'data_custom/images/docs/sup_running_agency/funny.jpg',

            'docs/pages/comcode_custom/EN/atag.txt',
            'docs/pages/comcode_custom/EN/codebook.txt',
            'docs/pages/comcode_custom/EN/codebook_1.txt',
            'docs/pages/comcode_custom/EN/codebook_1b.txt',
            'docs/pages/comcode_custom/EN/codebook_2.txt',
            'docs/pages/comcode_custom/EN/codebook_3.txt',
            'docs/pages/comcode_custom/EN/faq.txt',
            'docs/pages/comcode_custom/EN/sup_inline_editing.txt',
            'docs/pages/comcode_custom/EN/sup_a_detailed_look_at_the_composr_calendar_system.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_booking_system_to_your_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_chatroom_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_download_library_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_new_poll_to_your_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_new_zone_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_sub_forum_to_your_composr_forum.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_survey_to_an_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_add_a_twitter_feed_block_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_add_shoutboxes_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_adding_an_activity_feed_to_your_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_adding_an_image_slider_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_adding_banners_to_your_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_adding_new_page_options_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_an_introduction_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_an_overview_of_galleries_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_backing_up_your_composr_installation.txt',
            'docs/pages/comcode_custom/EN/sup_catalogues.txt',
            'docs/pages/comcode_custom/EN/sup_changing_the_composr_forums.txt',
            'docs/pages/comcode_custom/EN/sup_chrome_tools.txt',
            'docs/pages/comcode_custom/EN/sup_composr_101.txt',
            'docs/pages/comcode_custom/EN/sup_composr_custom_profile_fields_cpf.txt',
            'docs/pages/comcode_custom/EN/sup_composr_points_explained.txt',
            'docs/pages/comcode_custom/EN/sup_configure_the_news_display_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_converting_an_composr_gallery_to_a_carousel.txt',
            'docs/pages/comcode_custom/EN/sup_creating_a_hidden_members_zone_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_creating_a_store_locator_for_your_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_customising_your_composr_websites_design.txt',
            'docs/pages/comcode_custom/EN/sup_database_enums.txt',
            'docs/pages/comcode_custom/EN/sup_editing_menus_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_editing_site_wide_permissions_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_editing_the_composr_front_page.txt',
            'docs/pages/comcode_custom/EN/sup_explaining_the_composr_quiz_module.txt',
            'docs/pages/comcode_custom/EN/sup_finding_your_way_around_the_composr_adminzone.txt',
            'docs/pages/comcode_custom/EN/sup_forum_separation.txt',
            'docs/pages/comcode_custom/EN/sup_hardcore_1.txt',
            'docs/pages/comcode_custom/EN/sup_hardcore_2.txt',
            'docs/pages/comcode_custom/EN/sup_hardcore_3.txt',
            'docs/pages/comcode_custom/EN/sup_hardcore_blocks.txt',
            'docs/pages/comcode_custom/EN/sup_how_to_add_an_information_block_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_how_to_change_your_favicon_and_site_logo_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_how_to_close_or_open_your_composr_website.txt',
            'docs/pages/comcode_custom/EN/sup_how_to_conduct_an_upgrade_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_how_to_install_an_addon_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_install_a_theme_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_integrating_a_youtube_channel_to_composr.txt',
            'docs/pages/comcode_custom/EN/sup_join_disabling.txt',
            'docs/pages/comcode_custom/EN/sup_running_agency.txt',
            'docs/pages/comcode_custom/EN/sup_keeping_track_of_your_composr_site.txt',
            'docs/pages/comcode_custom/EN/sup_making_a_theme.txt',
            'docs/pages/comcode_custom/EN/sup_modsecurity.txt',
            'docs/pages/comcode_custom/EN/sup_partner_sites_and_debranding_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_security_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_sending_email_newsletters_in_composr_part_1.txt',
            'docs/pages/comcode_custom/EN/sup_sending_email_newsletters_in_composr_part_2.txt',
            'docs/pages/comcode_custom/EN/sup_set_a_recurring_event_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_set_up_a_workflow_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_set_up_short_urls_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_setting_timed_content_for_composr_and_your_arvixe_webhosting.txt',
            'docs/pages/comcode_custom/EN/sup_setting_up_a_map_of_your_composr_users_locations.txt',
            'docs/pages/comcode_custom/EN/sup_setting_up_a_new_composr_forum.txt',
            'docs/pages/comcode_custom/EN/sup_setting_up_classified_ads_on_composr.txt',
            'docs/pages/comcode_custom/EN/sup_setting_up_google_ads_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_setup_a_new_usergroup_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_setup_a_private_members_forum_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_setup_a_wiki_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_site_cloning.txt',
            'docs/pages/comcode_custom/EN/sup_catalogue_field_references.txt',
            'docs/pages/comcode_custom/EN/sup_stopping_spammers_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_taking_a_look_at_seo_on_composr.txt',
            'docs/pages/comcode_custom/EN/sup_taking_a_more_detailed_look_at_composr_catalogues_system.txt',
            'docs/pages/comcode_custom/EN/sup_updating_the_members_listing_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_using_the_if_in_group_tag_in_composr.txt',
            'docs/pages/comcode_custom/EN/sup_web_standards_in_composr.txt',
            'docs/pages/comcode_custom/EN/tut_accessibility.txt',
            'docs/pages/comcode_custom/EN/tut_addon_index.txt',
            'docs/pages/comcode_custom/EN/tut_adminzone.txt',
            'docs/pages/comcode_custom/EN/tut_adv_comcode.txt',
            'docs/pages/comcode_custom/EN/tut_adv_comcode_pages.txt',
            'docs/pages/comcode_custom/EN/tut_adv_configuration.txt',
            'docs/pages/comcode_custom/EN/tut_adv_downloads.txt',
            'docs/pages/comcode_custom/EN/tut_adv_galleries.txt',
            'docs/pages/comcode_custom/EN/tut_adv_install.txt',
            'docs/pages/comcode_custom/EN/tut_adv_members.txt',
            'docs/pages/comcode_custom/EN/tut_adv_news.txt',
            'docs/pages/comcode_custom/EN/tut_adv_permissions.txt',
            'docs/pages/comcode_custom/EN/tut_adv_structure.txt',
            'docs/pages/comcode_custom/EN/tut_aggregate_types.txt',
            'docs/pages/comcode_custom/EN/tut_antispam.txt',
            'docs/pages/comcode_custom/EN/tut_authors.txt',
            'docs/pages/comcode_custom/EN/tut_backup.txt',
            'docs/pages/comcode_custom/EN/tut_banners.txt',
            'docs/pages/comcode_custom/EN/tut_browsers.txt',
            'docs/pages/comcode_custom/EN/tut_calendar.txt',
            'docs/pages/comcode_custom/EN/tut_catalogues.txt',
            'docs/pages/comcode_custom/EN/tut_censor.txt',
            'docs/pages/comcode_custom/EN/tut_chat.txt',
            'docs/pages/comcode_custom/EN/tut_chmod.txt',
            'docs/pages/comcode_custom/EN/tut_cleanup.txt',
            'docs/pages/comcode_custom/EN/tut_collaboration.txt',
            'docs/pages/comcode_custom/EN/tut_comcode.txt',
            'docs/pages/comcode_custom/EN/tut_comcode_pages.txt',
            'docs/pages/comcode_custom/EN/tut_commandr.txt',
            'docs/pages/comcode_custom/EN/tut_configuration.txt',
            'docs/pages/comcode_custom/EN/tut_cookies.txt',
            'docs/pages/comcode_custom/EN/tut_correspondence.txt',
            'docs/pages/comcode_custom/EN/tut_design.txt',
            'docs/pages/comcode_custom/EN/tut_designer_themes.txt',
            'docs/pages/comcode_custom/EN/tut_disaster.txt',
            'docs/pages/comcode_custom/EN/tut_do.txt',
            'docs/pages/comcode_custom/EN/tut_domain_names.txt',
            'docs/pages/comcode_custom/EN/tut_downloads.txt',
            'docs/pages/comcode_custom/EN/tut_drinking.txt',
            'docs/pages/comcode_custom/EN/tut_ecommerce.txt',
            'docs/pages/comcode_custom/EN/tut_email.txt',
            'docs/pages/comcode_custom/EN/tut_emoticons.txt',
            'docs/pages/comcode_custom/EN/tut_facebook.txt',
            'docs/pages/comcode_custom/EN/tut_featured.txt',
            'docs/pages/comcode_custom/EN/tut_feedback.txt',
            'docs/pages/comcode_custom/EN/tut_fields.txt',
            'docs/pages/comcode_custom/EN/tut_fields_filter.txt',
            'docs/pages/comcode_custom/EN/tut_filtercode.txt',
            'docs/pages/comcode_custom/EN/tut_fixed_width.txt',
            'docs/pages/comcode_custom/EN/tut_forum_tracking.txt',
            'docs/pages/comcode_custom/EN/tut_forums.txt',
            'docs/pages/comcode_custom/EN/tut_framework.txt',
            'docs/pages/comcode_custom/EN/tut_fringe.txt',
            'docs/pages/comcode_custom/EN/tut_galleries.txt',
            'docs/pages/comcode_custom/EN/tut_google_analytics.txt',
            'docs/pages/comcode_custom/EN/tut_google_appengine.txt',
            'docs/pages/comcode_custom/EN/tut_hardcore_minimodules.txt',
            'docs/pages/comcode_custom/EN/tut_how_internet_works.txt',
            'docs/pages/comcode_custom/EN/tut_httpauth.txt',
            'docs/pages/comcode_custom/EN/tut_importer.txt',
            'docs/pages/comcode_custom/EN/tut_information.txt',
            'docs/pages/comcode_custom/EN/tut_install.txt',
            'docs/pages/comcode_custom/EN/tut_integration.txt',
            'docs/pages/comcode_custom/EN/tut_intl.txt',
            'docs/pages/comcode_custom/EN/tut_intl_code_philosophy.txt',
            'docs/pages/comcode_custom/EN/tut_intl_content.txt',
            'docs/pages/comcode_custom/EN/tut_intl_users.txt',
            'docs/pages/comcode_custom/EN/tut_keymap.txt',
            'docs/pages/comcode_custom/EN/tut_ldap.txt',
            'docs/pages/comcode_custom/EN/tut_legal.txt',
            'docs/pages/comcode_custom/EN/tut_markup.txt',
            'docs/pages/comcode_custom/EN/tut_members.txt',
            'docs/pages/comcode_custom/EN/tut_menus.txt',
            'docs/pages/comcode_custom/EN/tut_metadata.txt',
            'docs/pages/comcode_custom/EN/tut_mobile.txt',
            'docs/pages/comcode_custom/EN/tut_mobile_sdk.txt',
            'docs/pages/comcode_custom/EN/tut_moderation.txt',
            'docs/pages/comcode_custom/EN/tut_moving.txt',
            'docs/pages/comcode_custom/EN/tut_msn.txt',
            'docs/pages/comcode_custom/EN/tut_news.txt',
            'docs/pages/comcode_custom/EN/tut_newsletter.txt',
            'docs/pages/comcode_custom/EN/tut_notifications.txt',
            'docs/pages/comcode_custom/EN/tut_nuances.txt',
            'docs/pages/comcode_custom/EN/tut_optimisation.txt',
            'docs/pages/comcode_custom/EN/tut_permissions.txt',
            'docs/pages/comcode_custom/EN/tut_points.txt',
            'docs/pages/comcode_custom/EN/tut_programming.txt',
            'docs/pages/comcode_custom/EN/tut_quizzes.txt',
            'docs/pages/comcode_custom/EN/tut_releasing_themes.txt',
            'docs/pages/comcode_custom/EN/tut_repository.txt',
            'docs/pages/comcode_custom/EN/tut_search.txt',
            'docs/pages/comcode_custom/EN/tut_security.txt',
            'docs/pages/comcode_custom/EN/tut_selectcode.txt',
            'docs/pages/comcode_custom/EN/tut_seo.txt',
            'docs/pages/comcode_custom/EN/tut_short_urls.txt',
            'docs/pages/comcode_custom/EN/tut_software_feedback.txt',
            'docs/pages/comcode_custom/EN/tut_sql.txt',
            'docs/pages/comcode_custom/EN/tut_staff.txt',
            'docs/pages/comcode_custom/EN/tut_staff_advice.txt',
            'docs/pages/comcode_custom/EN/tut_statistics.txt',
            'docs/pages/comcode_custom/EN/tut_structure.txt',
            'docs/pages/comcode_custom/EN/tut_subcom.txt',
            'docs/pages/comcode_custom/EN/tut_support_desk.txt',
            'docs/pages/comcode_custom/EN/tut_tempcode.txt',
            'docs/pages/comcode_custom/EN/tut_theme_lifecycle.txt',
            'docs/pages/comcode_custom/EN/tut_themes.txt',
            'docs/pages/comcode_custom/EN/tut_trace.txt',
            'docs/pages/comcode_custom/EN/tut_uninstall.txt',
            'docs/pages/comcode_custom/EN/tut_upgrade.txt',
            'docs/pages/comcode_custom/EN/tut_users.txt',
            'docs/pages/comcode_custom/EN/tut_webhosting.txt',
            'docs/pages/comcode_custom/EN/tut_webapp.txt',
            'docs/pages/comcode_custom/EN/tut_wiki.txt',
            'docs/pages/comcode_custom/EN/tut_windows.txt',
            'docs/pages/comcode_custom/EN/tut_wysiwyg.txt',
            'docs/pages/comcode_custom/EN/sup_complex_projects.txt',
            'docs/pages/comcode_custom/EN/sup_customer_feedback.txt',
            'docs/pages/comcode_custom/EN/sup_developer_relationships.txt',
            'docs/pages/comcode_custom/EN/sup_irrational_behaviour.txt',
            'docs/pages/comcode_custom/EN/sup_minimum_viable_products.txt',
            'docs/pages/comcode_custom/EN/sup_pricing.txt',
            'docs/pages/comcode_custom/EN/sup_project_management.txt',
            'docs/pages/comcode_custom/EN/sup_choosing_a_developer.txt',
            'docs/pages/comcode_custom/EN/sup_marketing.txt',
            'docs/pages/comcode_custom/EN/sup_making_tutorials.txt',
            'docs/pages/comcode_custom/EN/sup_glossary.txt',
            'docs/pages/comcode_custom/EN/sup_professional_upgrading.txt',
            'docs/pages/comcode_custom/EN/sup_postgresql.txt',
            'docs/pages/comcode_custom/EN/sup_sqlserver.txt',
            'docs/pages/comcode_custom/EN/sup_youtube_channel_integration_block_addon_documentation.txt',
            'docs/pages/comcode_custom/EN/tut_intl_maintenance.txt',
            'docs/pages/comcode_custom/EN/sup_conposr.txt',

            'docs/composr-api-template/README.md',
            'docs/composr-api-template/class.xsl',
            'docs/composr-api-template/css/bootstrap-responsive.css',
            'docs/composr-api-template/css/bootstrap-responsive.min.css',
            'docs/composr-api-template/css/bootstrap.css',
            'docs/composr-api-template/css/bootstrap.min.css',
            'docs/composr-api-template/css/jquery.iviewer.css',
            'docs/composr-api-template/css/prettify.css',
            'docs/composr-api-template/css/template.css',
            'docs/composr-api-template/elements/class.xsl',
            'docs/composr-api-template/elements/common.xsl',
            'docs/composr-api-template/elements/constant.xsl',
            'docs/composr-api-template/elements/function.xsl',
            'docs/composr-api-template/elements/namespace.xsl',
            'docs/composr-api-template/elements/package.xsl',
            'docs/composr-api-template/elements/property.xsl',
            'docs/composr-api-template/graph.html',
            'docs/composr-api-template/graphs/class.xsl',
            'docs/composr-api-template/img/apple-touch-icon-114x114.png',
            'docs/composr-api-template/img/apple-touch-icon-72x72.png',
            'docs/composr-api-template/img/apple-touch-icon.png',
            'docs/composr-api-template/img/favicon.ico',
            'docs/composr-api-template/img/glyphicons-halflings-white.png',
            'docs/composr-api-template/img/glyphicons-halflings.png',
            'docs/composr-api-template/img/icons/class.png',
            'docs/composr-api-template/img/icons/constant.png',
            'docs/composr-api-template/img/icons/function.png',
            'docs/composr-api-template/img/icons/icon-folder-open-big.png',
            'docs/composr-api-template/img/icons/icon-th-big.png',
            'docs/composr-api-template/img/icons/icon_template.svg',
            'docs/composr-api-template/img/icons/interface.png',
            'docs/composr-api-template/img/icons/method.png',
            'docs/composr-api-template/img/icons/property.png',
            'docs/composr-api-template/img/iviewer/grab.cur',
            'docs/composr-api-template/img/iviewer/hand.cur',
            'docs/composr-api-template/img/iviewer/iviewer.rotate_left.png',
            'docs/composr-api-template/img/iviewer/iviewer.rotate_right.png',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_fit.png',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_fit2.gif',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_in.png',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_in2.gif',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_out.png',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_out2.gif',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_zero.png',
            'docs/composr-api-template/img/iviewer/iviewer.zoom_zero2.gif',
            'docs/composr-api-template/img/loader.gif',
            'docs/composr-api-template/index.xsl',
            'docs/composr-api-template/js/bootstrap.js',
            'docs/composr-api-template/js/bootstrap.min.js',
            'docs/composr-api-template/js/jquery.iviewer.js',
            'docs/composr-api-template/js/jquery.iviewer.min.js',
            'docs/composr-api-template/js/jquery.mousewheel.min.js',
            'docs/composr-api-template/js/prettify/lang-apollo.js',
            'docs/composr-api-template/js/prettify/lang-clj.js',
            'docs/composr-api-template/js/prettify/lang-css.js',
            'docs/composr-api-template/js/prettify/lang-go.js',
            'docs/composr-api-template/js/prettify/lang-hs.js',
            'docs/composr-api-template/js/prettify/lang-lisp.js',
            'docs/composr-api-template/js/prettify/lang-lua.js',
            'docs/composr-api-template/js/prettify/lang-ml.js',
            'docs/composr-api-template/js/prettify/lang-n.js',
            'docs/composr-api-template/js/prettify/lang-proto.js',
            'docs/composr-api-template/js/prettify/lang-scala.js',
            'docs/composr-api-template/js/prettify/lang-sql.js',
            'docs/composr-api-template/js/prettify/lang-tex.js',
            'docs/composr-api-template/js/prettify/lang-vb.js',
            'docs/composr-api-template/js/prettify/lang-vhdl.js',
            'docs/composr-api-template/js/prettify/lang-wiki.js',
            'docs/composr-api-template/js/prettify/lang-xq.js',
            'docs/composr-api-template/js/prettify/lang-yaml.js',
            'docs/composr-api-template/js/prettify/prettify.min.js',
            'docs/composr-api-template/js/template.js',
            'docs/composr-api-template/layout.xsl',
            'docs/composr-api-template/namespaces.xsl',
            'docs/composr-api-template/packages.xsl',
            'docs/composr-api-template/reports/deprecated.xsl',
            'docs/composr-api-template/reports/errors.xsl',
            'docs/composr-api-template/reports/markers.xsl',
            'docs/composr-api-template/search.json.xsl',
            'docs/composr-api-template/template.xml',
            'docs/composr-api-template/diff.diff',
            'docs/composr-api-template/img/icons/arrow_down.png',
            'docs/composr-api-template/img/icons/arrow_right.png',
            'docs/composr-api-template/img/icons/favicon.ico',
            'docs/composr-api-template/img/icons/file-php.png',
            'docs/composr-api-template/img/icons/file.gif',
            'docs/composr-api-template/img/icons/folder.gif',
            'docs/composr-api-template/img/icons/ok.png',
            'docs/composr-api-template/img/icons/search.gif',
            'docs/composr-api-template/img/icons/variable.png',
            'docs/composr-api-template/img/icons/view_source.png',
            'docs/composr-api-template/img/icons/visibility_private.png',
            'docs/composr-api-template/img/icons/visibility_protected.png',
            'docs/composr-api-template/img/icons/visibility_public.png',
            'docs/composr-api-template/js/jqplot/changes.txt',
            'docs/composr-api-template/js/jqplot/copyright.txt',
            'docs/composr-api-template/js/jqplot/excanvas.min.js',
            'docs/composr-api-template/js/jqplot/gpl-2.0.txt',
            'docs/composr-api-template/js/jqplot/jquery.jqplot.min.css',
            'docs/composr-api-template/js/jqplot/jquery.jqplot.min.js',
            'docs/composr-api-template/js/jqplot/MIT-LICENSE.txt',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.barRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.BezierCurveRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.blockRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.bubbleRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.canvasAxisLabelRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.canvasAxisTickRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.canvasOverlay.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.canvasTextRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.categoryAxisRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.ciParser.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.cursor.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.dateAxisRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.donutRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.dragable.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.enhancedLegendRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.funnelRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.highlighter.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.json2.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.logAxisRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.mekkoAxisRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.mekkoRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.meterGaugeRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.mobile.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.ohlcRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.pieRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.pointLabels.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.pyramidAxisRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.pyramidGridRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.pyramidRenderer.min.js',
            'docs/composr-api-template/js/jqplot/plugins/jqplot.trendline.min.js',
            'docs/composr-api-template/js/jqplot/README.txt',
            'docs/composr-api-template/js/jquery-1.4.2.min.js',
            'docs/composr-api-template/js/jquery-1.7.1.min.js',
            'docs/composr-api-template/js/jquery-ui-1.8.2.custom.min.js',
            'docs/composr-api-template/js/jquery.cookie.js',
            'docs/composr-api-template/js/jquery.panzoom.js',
            'docs/composr-api-template/js/jquery.splitter.js',
            'docs/composr-api-template/js/jquery.tools.min.js',
            'docs/composr-api-template/js/jquery.treeview.js',
            'docs/composr-api-template/js/jquery.xml2json.js',
            'docs/composr-api-template/js/menu.js',
            'docs/composr-api-template/js/sidebar.js',
            'docs/composr-api-template/js/SVGPan.js',

            'themes/default/images_custom/tutorial_icons/addon.png',
            'themes/default/images_custom/tutorial_icons/administration.png',
            'themes/default/images_custom/tutorial_icons/advice_and_guidance.png',
            'themes/default/images_custom/tutorial_icons/analytics.png',
            'themes/default/images_custom/tutorial_icons/banners.png',
            'themes/default/images_custom/tutorial_icons/book.png',
            'themes/default/images_custom/tutorial_icons/business_development.png',
            'themes/default/images_custom/tutorial_icons/calendar.png',
            'themes/default/images_custom/tutorial_icons/catalogues.png',
            'themes/default/images_custom/tutorial_icons/chatrooms.png',
            'themes/default/images_custom/tutorial_icons/collaboration.png',
            'themes/default/images_custom/tutorial_icons/configuration.png',
            'themes/default/images_custom/tutorial_icons/content.png',
            'themes/default/images_custom/tutorial_icons/contributing.png',
            'themes/default/images_custom/tutorial_icons/css.png',
            'themes/default/images_custom/tutorial_icons/design_and_themeing.png',
            'themes/default/images_custom/tutorial_icons/development.png',
            'themes/default/images_custom/tutorial_icons/downloads.png',
            'themes/default/images_custom/tutorial_icons/ecommerce.png',
            'themes/default/images_custom/tutorial_icons/feedback_features.png',
            'themes/default/images_custom/tutorial_icons/forum.png',
            'themes/default/images_custom/tutorial_icons/fun_and_games.png',
            'themes/default/images_custom/tutorial_icons/galleries.png',
            'themes/default/images_custom/tutorial_icons/installation.png',
            'themes/default/images_custom/tutorial_icons/internationalisation.png',
            'themes/default/images_custom/tutorial_icons/introduction.png',
            'themes/default/images_custom/tutorial_icons/javascript.png',
            'themes/default/images_custom/tutorial_icons/maintenance.png',
            'themes/default/images_custom/tutorial_icons/members.png',
            'themes/default/images_custom/tutorial_icons/news.png',
            'themes/default/images_custom/tutorial_icons/newsletters.png',
            'themes/default/images_custom/tutorial_icons/opinion.png',
            'themes/default/images_custom/tutorial_icons/pages.png',
            'themes/default/images_custom/tutorial_icons/performance.png',
            'themes/default/images_custom/tutorial_icons/php.png',
            'themes/default/images_custom/tutorial_icons/power_tools.png',
            'themes/default/images_custom/tutorial_icons/security.png',
            'themes/default/images_custom/tutorial_icons/seo.png',
            'themes/default/images_custom/tutorial_icons/social.png',
            'themes/default/images_custom/tutorial_icons/structure_and_navigation.png',
            'themes/default/images_custom/tutorial_icons/support.png',
            'themes/default/images_custom/tutorial_icons/third_party_integration.png',
            'themes/default/images_custom/tutorial_icons/upgrading.png',
            'themes/default/images_custom/tutorial_icons/webhosting.png',
            'themes/default/images_custom/tutorial_icons/web_standards_and_accessibility.png',
            'themes/default/images_custom/tutorial_icons/wiki.png',
            'themes/default/images_custom/tutorial_icons/internet_technology.png',
            'themes/default/images_custom/tutorial_icons/mobile.png',
            'themes/default/images_custom/tutorial_icons/video.png',
            'docs/codebook_data_dictionary.docx',
            'docs/custom_modules_example__pty.zip',
            'docs/erd_rendered__by_addon.zip',
            'docs/erd_sql__by_addon.zip',
            'docs/league_standings__example_addon.zip',
            'docs/making_a_theme.pdf',
            'docs/standards-checklist.xls',
        );
    }
}
